.. Frontmatter/Introduction comes from the repo's README.rst
.. include:: ../../README.rst
  :start-after: cut-here

.. toctree::
   :maxdepth: 2
   :caption: User Guide

   installing
   configuring

.. toctree::
   :maxdepth: 2
   :caption: Developer Documentation

   api-python
   examples
   contributing

.. toctree::
   :maxdepth: 2
   :caption: Package Status

   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

